@@ -1,5 +1,5 @@
 /*
- *       File name:  libcnlua/commands.cc
+ *       File name:  lua-cnrun/commands.cc
  *         Project:  cnrun
  *          Author:  Andrei Zavada <johnhommer@gmail.com>
  *                   building on original work by Thomas Nowotny <tnowotny@ucsd.edu>
@@ -176,16 +176,6 @@ int new_model( lua_State *L)
 }
 
 
-int delete_model( lua_State *L)
-{
-        INTRO_WITH_MODEL_NAME("ps");
-
-        C.del_model( model_name);
-
-        VOID_RETURN;
-}
-
-
 int list_models( lua_State *L)
 {
         INTRO_WITH_CONTEXT("p");
@@ -207,6 +197,20 @@ int list_models( lua_State *L)
                         __FUNCTION__, model_name); \
         auto& M = *C.get_model(model_name);
 
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-variable"
+int delete_model( lua_State *L)
+{
+        INTRO_WITH_MODEL("ps");
+
+        C.del_model( model_name);
+
+        VOID_RETURN;
+}
+#pragma GCC diagnostic pop
+
+
 int import_nml( lua_State *L)
 {
         INTRO_WITH_MODEL("pss");
@@ -442,8 +446,10 @@ int new_neuron( lua_State *L)
                 *type  = lua_tostring( L, 3),
                 *label = lua_tostring( L, 4);
 
+        string population, id;
+        C_BaseUnit::extract_nml_parts( label, &population, &id);
         if ( !M.add_neuron_species(
-                     type, label,
+                     type, population.c_str(), id.c_str(),
                      TIncludeOption::is_last) )
                 return make_error(
                         L, "%s(%s): error", __FUNCTION__, model_name);
@@ -961,6 +967,27 @@ int stop_log_spikes( lua_State *L)
 }
 
 
+
+
+/*
+int discover_peers( lua_State *L)
+{
+}
+
+int query_peer_state( lua_State *L)
+{
+}
+
+int query_peer_accepting_neurons( lua_State *L)
+{
+}
+
+int extend_peer_sources( lua_State *L)
+{
+}
+*/
+
+
 // all together now:
 const struct luaL_Reg cnlib [] = {
 #define BLOOP(X) {#X, X}
